@@ -2,10 +2,6 @@ stop0 = function(...) {
   stop(..., call. = FALSE)
 }
 
-warning0 = function(...) {
-  warning(..., call. = FALSE)
-}
-
 cat0 = function(...) {
   cat(..., sep = "")
 }
@@ -23,7 +19,3 @@ format_name_value_pairs = function(x, defaults = list()) {
     )
   }
 }
-
-bullet = function(x) {
-  paste0(strwrap(paste0("- ", x), exdent = 3, indent = 1), collapse = "\n")
-}
